(function(d){	const l = d['kk'] = d['kk'] || {};	l.dictionary=Object.assign(		l.dictionary||{},		{"Align center":"Ортадан туралау","Align left":"Солға туралау","Align right":"Оңға туралау",Justify:"","Text alignment":"Мәтінді туралау","Text alignment toolbar":"Мәтінді туралау құралдар тақтасы"}	);l.getPluralForm=function(n){return (n!=1);;};})(window.CKEDITOR_TRANSLATIONS||(window.CKEDITOR_TRANSLATIONS={}));