"""Contains constants for the users app."""

import re

BRAND_ICONS = {
    "amazon": "amazon",
    "amazon_cognito": "amazon",
    "angellist": "angellist",
    "apple": "apple",
    "atlassian": "atlassian",
    "battlenet": "battle-net",
    "bitbucket_oauth2": "bitbucket",
    "digitalocean": "digital-ocean",
    "discord": "discord",
    "dropbox": "dropbox",
    "evernote": "evernote",
    "facebook": "facebook",
    "figma": "figma",
    "fivehundredpx": "500px",
    "flickr": "flickr",
    "foursquare": "foursquare",
    "github": "github",
    "gitlab": "gitlab",
    "google": "google",
    "hubspot": "hubspot",
    "instagram": "instagram",
    "line": "line",
    "linkedin_oauth2": "linkedin",
    "mailchimp": "mailchimp",
    "mailru": "",
    "meetup": "meetup",
    "microsoft": "microsoft",
    "odnoklassniki": "odnoklassniki",
    "openid": "openid",
    "openid_connect": "openid",
    "orcid": "orcid",
    "patreon": "patreon",
    "paypal": "paypal",
    "pinterest": "pinterest",
    "pocket": "get-pocket",
    "reddit": "reddit",
    "salesforce": "salesforce",
    "shopify": "shopify",
    "slack": "slack",
    "snapchat": "snapchat",
    "soundcloud": "soundcloud",
    "spotify": "spotify",
    "stackexchange": "stack-exchange",
    "steam": "steam",
    "strava": "strava",
    "stripe": "stripe",
    "telegram": "telegram",
    "tiktok": "tiktok",
    "trello": "trello",
    "tumblr": "tumblr",
    "twitch": "twitch",
    "twitter": "twitter",
    "twitter_oauth2": "twitter",
    "untappd": "untappd",
    "vimeo": "vimeo",
    "vimeo_oauth2": "vimeo",
    "vk": "vk",
    "weibo": "weibo",
    "weixin": "weixin",
    "windowslive": "windows",
    "xing": "xing",
    "yahoo": "yahoo",
    "yandex": "yandex",
}
INT_RE = re.compile(r"^(0|[1-9]\d*)$")
SIZE_RE = re.compile(r"^([1-9]\d*)x([1-9]\d*)$")
