{% load i18n allauth %}
{% element alert %}
    {% slot message %}
    <strong>{% trans 'Warning:' %}</strong> {% trans "You currently do not have any email address set up. You should really add an email address so you can receive notifications, reset your password, etc." %}
    {% endslot %}
{% endelement %}
