(function(d){	const l = d['es-co'] = d['es-co'] || {};	l.dictionary=Object.assign(		l.dictionary||{},		{"(may require <kbd>Fn</kbd>)":"","%0 of %1":"%0 de %1",Accept:"",Accessibility:"","Accessibility help":"","Advanced options":"","Align center":"Centrar","Align left":"Alinear a la izquierda","Align right":"Alinear a la derecha",Aquamarine:"","Below, you can find a list of keyboard shortcuts that can be used in the editor.":"",Big:"Grande",Black:"","Block quote":"Cita de bloque",Blue:"","Blue marker":"Marcador azul",Bold:"Negrita","Bold text":"",Cancel:"Cancelar","Cannot upload file:":"No se pudo cargar el archivo:","Characters: %0":"Caracteres: %0",Clear:"","Click to edit block":"",Close:"","Close contextual balloons, dropdowns, and dialogs":"",Code:"Código","Code block":"","Content editing keystrokes":"","Copy selected content":"Copiar contenido seleccionado",Default:"Por defecto","Dim grey":"","Document colors":"Colores del documento","Drag to move":"","Dropdown toolbar":"","Edit block":"","Editor block content toolbar":"","Editor contextual toolbar":"","Editor dialog":"","Editor editing area: %0":"","Editor menu bar":"","Editor toolbar":"","Entering %0 code snippet":"","Entering code snippet":"","Execute the currently focused button. Executing buttons that interact with the editor content moves the focus back to the content.":"",Find:"","Find and replace":"","Find in text…":"","Find in the document":"","Font Background Color":"Color de fondo de fuente","Font Color":"Color de fuente","Font Family":"Familia de fuente","Font Size":"Tamaño de fuente",Green:"","Green marker":"Marcador verde","Green pen":"Pincel verde",Grey:"","Help Contents. To close this dialog press ESC.":"",HEX:"",Highlight:"Resaltar",Huge:"Enorme","Insert code block":"Insertar bloque de código",Italic:"Cursiva","Italic text":"Texto en cursiva",Justify:"Justificar","Leaving %0 code snippet":"","Leaving code snippet":"","Light blue":"","Light green":"","Light grey":"","Match case":"",MENU_BAR_MENU_EDIT:"Editar",MENU_BAR_MENU_FILE:"",MENU_BAR_MENU_FONT:"",MENU_BAR_MENU_FORMAT:"",MENU_BAR_MENU_HELP:"",MENU_BAR_MENU_INSERT:"Insertar",MENU_BAR_MENU_TEXT:"",MENU_BAR_MENU_TOOLS:"",MENU_BAR_MENU_VIEW:"","Move focus between form fields (inputs, buttons, etc.)":"","Move focus in and out of an active dialog window":"","Move focus to the menu bar, navigate between menu bars":"","Move focus to the toolbar, navigate between toolbars":"","Move out of an inline code style":"","Navigate through the toolbar or menu bar":"",Next:"","Next result":"","No results found":"","No searchable items":"","Open the accessibility help dialog":"",Orange:"","Paste content":"Pegar contenido","Paste content as plain text":"Pegar contenido como texto plano","Pink marker":"Marcador rosa","Plain text":"Texto plano","Please enter a valid color (e.g. \"ff0000\").":"","Press %0 for help.":"",Previous:"","Previous result":"",Purple:"",Red:"","Red pen":"Pincel rojo","Remove color":"Quitar color","Remove highlight":"Quitar resaltado",Replace:"Reemplazar","Replace all":"","Replace with…":"","Restore default":"Restaurar valores predeterminados","Revert autoformatting action":"Revertir la acción de formato automático","Rich Text Editor":"",Save:"Guardar","Show blocks":"Mostrar bloques","Show more items":"Mostrar más elementos",Small:"Pequeña",Strikethrough:"Tachado","Strikethrough text":"",Subscript:"Subíndice",Superscript:"Superíndice","Text alignment":"Alineación de texto","Text alignment toolbar":"Herramientas de alineación de texto","Text highlight toolbar":"Herramientas de resaltado de texto","Text to find must not be empty.":"","These keyboard shortcuts allow for quick access to content editing features.":"",Tiny:"Diminuta","Tip: Find some text first in order to replace it.":"","Toggle caption off":"","Toggle caption on":"",Turquoise:"",Underline:"Subrayado","Underline text":"","Upload in progress":"Carga en progreso","Use the following keystrokes for more efficient navigation in the CKEditor 5 user interface.":"","User interface and content navigation keystrokes":"",White:"","Whole words only":"","Words: %0":"Palabras: %0",Yellow:"","Yellow marker":"Marcador amarillo"}	);l.getPluralForm=function(n){return n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;;};})(window.CKEDITOR_TRANSLATIONS||(window.CKEDITOR_TRANSLATIONS={}));