{% load allauth %}
{% comment %} djlint:off {% endcomment %}
<{% if attrs.href %}a href="{{ attrs.href }}"{% else %}button{% endif %}
{% if attrs.form %}form="{{ attrs.form }}"{% endif %}
{% if attrs.id %}id="{{ attrs.id }}"{% endif %}
{% if attrs.name %}name="{{ attrs.name }}"{% endif %}
{% if attrs.value %}value="{{ attrs.value }}"{% endif %}
{% if attrs.type %}type="{{ attrs.type }}"{% endif %}
{% if attrs.title %}type="{{ attrs.title }}"{% endif %}
class="btn btn-sm {% if "danger" in attrs.tags %}btn-danger{% elif "secondary" in attrs.tags %}btn-secondary{% else %}btn-primary{% endif %}"
>
{% slot %}
{% endslot %}
</{% if attrs.href %}a{% else %}button{% endif %}>
