<script{% if async %} async{% endif %}{% if defer %} defer{% endif %} {% if type != 'text/javascript' %}type="{{ type }}" {% endif %}src="{{ url }}" {% if integrity %} integrity="{{ integrity }}"{% endif %}{% if crossorigin %} crossorigin="{{ crossorigin }}"{% endif %}></script>
