# Generated by Django 5.1 on 2024-08-23 16:32

import df_site.model_fields
from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("df_site", "0001_initial"),
    ]

    operations = [
        migrations.AlterField(
            model_name="alertribbon",
            name="message",
            field=df_site.model_fields.CKEditor5TextField(blank=True, default="", verbose_name="Message"),
        ),
        migrations.AlterField(
            model_name="alertribbon",
            name="summary",
            field=df_site.model_fields.CKEditor5CharField(db_index=True, max_length=100, verbose_name="Summary"),
        ),
    ]
