{% extends "account/base_manage_password.html" %}
{% load allauth i18n %}
{% block head_title %}
    {% trans "Change Password" %}
{% endblock head_title %}
{% block content %}
    {% element h1 %}
        {% trans "Change Password" %}
    {% endelement %}
    {% url 'account_change_password' as action_url %}
    {% element form form=form method="post" action=action_url %}
        {% slot body %}
            {% csrf_token %}
            {{ redirect_field }}
            {% element fields form=form %}
            {% endelement %}
        {% endslot %}
        {% slot actions %}
            {% element button type="submit" %}
                {% trans "Change Password" %}
            {% endelement %}
            {% url 'account_reset_password' as forgot_url %}
            {% element button href=forgot_url tags="danger,reset" %}
                {% trans "Forgot Password?" %}
            {% endelement %}
        {% endslot %}
    {% endelement %}
{% endblock content %}
