{% extends "postman/base.html" %}
{% load i18n static django_bootstrap5 %}
{% block extrahead %}{{ block.super }}
    {% if autocompleter_app.is_active %}{# using the available admin jQuery is enough #}
        {# should not be necessary since AS v1.3 with AJAX_SELECT_BOOTSTRAP set #}
        {#<script type="text/javascript" src="{% static 'admin/js/jquery.min.js' %}"></script>#}
    {% endif %}
    {{ form.media }}{# for ajax_selects (v1.3.6 at least) #}
{% endblock %}
{% block content %}
    <div id="postman">
        <h1 class="card-header text-center">{% block pm_write_title %}{% endblock %}</h1>
        <div class="card-body">
            <form action="{% if next_url %}?next={{ next_url|urlencode }}{% endif %}"
                  method="post">{% csrf_token %}
                <table>
                    {% block pm_write_recipient %}{% endblock %}
                </table>
                {% bootstrap_form form layout='floating' %}
                <div class="btn-group" role="group">
                    <button type="submit" class="pm_btn pm_btn-send btn btn-primary btn-sm">{% trans "Send" %}</button>
                </div>
            </form>
        </div>
    </div>
{% endblock %}
