{% extends "df_site/app.html" %}

{% load  i18n df_site %}

{% block body_banner %}
    <div class="page-header" id="banner">
        <div class="row">
            <div class="col-lg-8 col-md-7 col-sm-6">
                <h1>{% trans "Cookies" %}</h1>
                <p class="lead">{% trans 'This is a list of the categories of cookies used in our website and why we use them.' %}</p>
            </div>
            <div class="col-lg-4 col-md-5 col-sm-6"></div>
        </div>
    </div>
{% endblock body_banner %}


{% block body_content %}
    {% for cookie_group in object_list %}
        {% include "cookie_consent/_cookie_group.html" %}
    {% endfor %}

{% endblock body_content %}
