{% extends "postman/base_folder.html" %}
{% load i18n %}
{% block pm_folder_title %}{% trans "Received Messages" %}{% endblock %}
{% block pm_undelete_button %}{% endblock %}
{% block pm_recipient_header %}{% endblock %}
{% block pm_date %}{% trans "Received" %}{% endblock %}
{% block pm_recipient_cell %}{% endblock %}
