(function(d){	const l = d['si'] = d['si'] || {};	l.dictionary=Object.assign(		l.dictionary||{},		{"%0 of %1":"",Accept:"",Bold:"තදකුරු","Bold text":"","Break text":"","Bulleted List":"බුලටිත ලැයිස්තුව","Bulleted list styles toolbar":"",Cancel:"","Cannot upload file:":"ගොනුව යාවත්කාලීන කළ නොහැක:","Caption for image: %0":"","Caption for the image":"","Centered image":"","Change image text alternative":"",Circle:"",Clear:"","Close contextual balloons, dropdowns, and dialogs":"",Code:"","Content editing keystrokes":"",Custom:"","Custom image size":"",Decimal:"","Decimal with leading zero":"","Decrease list item indent":"",Disc:"","Enter image caption":"","Entering a to-do list":"","Error during image upload":"","Execute the currently focused button. Executing buttons that interact with the editor content moves the focus back to the content.":"","From computer":"","Full size image":"",Image:"","Image from computer":"","Image resize list":"","Image toolbar":"","Image upload complete":"","Image via URL":"","image widget":"","In line":"","Increase list item indent":"","Insert image":"පින්තූරය ඇතුල් කරන්න","Insert image via URL":"","Insert via URL":"","Invalid start index value.":"",Italic:"ඇලකුරු","Italic text":"","Keystrokes that can be used in a list":"","Leaving a to-do list":"","Left aligned image":"","List properties":"","Lower-latin":"","Lower–roman":"","Move focus between form fields (inputs, buttons, etc.)":"","Move focus to the menu bar, navigate between menu bars":"","Move focus to the toolbar, navigate between toolbars":"","Move out of an inline code style":"","Navigate through the toolbar or menu bar":"","Numbered List":"අංකිත ලැයිස්තුව","Numbered list styles toolbar":"","Open the accessibility help dialog":"",Original:"",Redo:"නැවත කරන්න","Remove color":"","Replace from computer":"","Replace image":"","Replace image from computer":"","Resize image":"","Resize image (in %0)":"","Resize image to %0":"","Resize image to the original size":"","Restore default":"","Reversed order":"","Right aligned image":"",Save:"","Show more items":"","Side image":"",Square:"","Start at":"","Start index must be greater than 0.":"",Strikethrough:"","Strikethrough text":"",Subscript:"",Superscript:"","Text alternative":"","The value must not be empty.":"","The value should be a plain number.":"","These keyboard shortcuts allow for quick access to content editing features.":"","To-do List":"","Toggle caption off":"","Toggle caption on":"","Toggle the circle list style":"","Toggle the decimal list style":"","Toggle the decimal with leading zero list style":"","Toggle the disc list style":"","Toggle the lower–latin list style":"","Toggle the lower–roman list style":"","Toggle the square list style":"","Toggle the upper–latin list style":"","Toggle the upper–roman list style":"",Underline:"","Underline text":"",Undo:"අහෝසි කරන්න","Update image URL":"","Upload failed":"උඩුගත කිරීම අසාර්ථක විය","Upload from computer":"","Upload image from computer":"","Uploading image":"","Upper-latin":"","Upper-roman":"","Use the following keystrokes for more efficient navigation in the CKEditor 5 user interface.":"","User interface and content navigation keystrokes":"","Via URL":"","Wrap text":""}	);l.getPluralForm=function(n){return (n != 1);;};})(window.CKEDITOR_TRANSLATIONS||(window.CKEDITOR_TRANSLATIONS={}));