{% extends "postman/base_folder.html" %}
{% load i18n allauth %}
{% block pm_folder_title %}{% trans "Archived Messages" %}{% endblock %}
{% block pm_archive_button %}{% endblock %}
{% block pm_undelete_button %}{% endblock %}
{% block pm_footer_info %}
    <p class="alert alert-info">{% trans "Messages in this folder will never be removed. You can use this folder for long term storage." %}</p>
{% endblock %}
