{% load i18n df_site %}
<details data-filter-title="{{ title }}" open class="list-group list-group-flush">
    <summary class="list-group-item list-group-item-light bg-body-secondary">
        {% blocktranslate with filter_title=title %} By {{ filter_title }} {% endblocktranslate %}
    </summary>
    {% for choice in choices %}
        {% if choice.selected %}
            <a class="list-group-item active d-flex justify-content-between align-items-center" href="{{ choice.query_string|iriencode }}">{% component_auto_badge choice.display extra_class='' color='light' %}</a>
        {% else %}
            <a class="list-group-item d-flex justify-content-between align-items-center" href="{{ choice.query_string|iriencode }}">{% component_auto_badge choice.display extra_class='' %}</a>
        {% endif %}
    {% endfor %}
</details>
